# Diagrams
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/diagrams#overview)
  * [Diagram Types](https://help.sap.com/docs/leanix/ea/diagrams#diagram-types)
  * [Accessing Diagrams](https://help.sap.com/docs/leanix/ea/diagrams#accessing-diagrams)
  * [Benefits](https://help.sap.com/docs/leanix/ea/diagrams#benefits)
  * [Difference Between Diagrams and Reports](https://help.sap.com/docs/leanix/ea/diagrams#difference-between-diagrams-and-reports)
  * [Editing versus Viewing Diagrams](https://help.sap.com/docs/leanix/ea/diagrams#editing-versus-viewing-diagrams)
  * [Using Diagram Templates](https://help.sap.com/docs/leanix/ea/diagrams#using-diagram-templates)
  * [Finding and Organizing Diagrams](https://help.sap.com/docs/leanix/ea/diagrams#finding-and-organizing-diagrams)


View all
